Lengths class

Constructors

Lengths(BuildContext context)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

height() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padding16() → double
toString() → String
A string representation of this object.
inherited
width() → double

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

context ↔ dynamic
getter/setter pair